/********************************************************************
 * Project:    STM32-ComStick
 * File:       startup.c
 *
 * System:     Cortex-M3 32 Bit (STM32F10x)
 * Compiler:   GNU Cortex 4.4.0
 *
 * Date:       2008/03/19
 * Author:     Application@Hitex.de
 *
 * Rights:     Hitex Development Tools GmbH
 *             Greschbachstr. 12
 *             D-76229 Karlsruhe
 ********************************************************************
 * Description:
 *
 * This file is part of the Clock Example "Clock" for GNU compiler.
 * This application is inteted to run on the MCBSTM32 board.
 * Function :
 *
 ********************************************************************
 *
 * WARRANTY:  HITEX warrants that the media on which the SOFTWARE is
 * furnished is free from defects in materials and workmanship under
 * normal use and service for a period of ninety (90) days. HITEX entire
 * liability and your exclusive remedy shall be the replacement of the
 * SOFTWARE if the media is defective. This Warranty is void if failure
 * of the media resulted from unauthorized modification, accident, abuse,
 * or misapplication.
 *
 * DISCLAIMER:  OTHER THAN THE ABOVE WARRANTY, THE SOFTWARE IS FURNISHED
 * "AS IS" WITHOUT WARRANTY OF ANY KIND. HITEX DISCLAIMS ALL OTHER WARRANTIES,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * NEITHER HITEX NOR ITS AFFILIATES SHALL BE LIABLE FOR ANY DAMAGES ARISING
 * OUT OF THE USE OF OR INABILITY TO USE THE SOFTWARE, INCLUDING DAMAGES FOR
 * LOSS OF PROFITS, BUSINESS INTERRUPTION, OR ANY SPECIAL, INCIDENTAL, INDIRECT
 * OR CONSEQUENTIAL DAMAGES EVEN IF HITEX HAS BEEN ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGES.
 ********************************************************************/

#include "stm32f10x_it.h"

#define global extern   // to declare external variables and functions
#include "main.h"


extern void main ( void );
#undef global
#define global          // to declare global variables and functions

/*******************************************************************************
* Prototypes
*******************************************************************************/

void Reset(void);
void NMIException(void);
void HardFaultException(void);
void DefaultHandler(void)__attribute__((noreturn));

/*******************************************************************************
* main Prototype
*******************************************************************************/

/*******************************************************************************
* Stack Size Definition
*******************************************************************************/

#ifndef STACK_SIZE
#define STACK_SIZE                              400
#endif

static unsigned long RAMStack[STACK_SIZE] __attribute__ ((section("stack")));

/*******************************************************************************
* Interrupt Vector Table
*******************************************************************************/

void (* const Interrupts[])(void) __attribute__ ((section("vector"))) =
{
   (void (*)(void))((unsigned long)RAMStack + sizeof(RAMStack)),
                                          // The initial stack pointer
   Reset,                                 // 1 reset handler
   NMIException,                          // 2 NMI handler
   HardFaultException,                    // 3 hard fault handler
   MemManageException,                    // 4 MPU fault handler
   BusFaultException,                     // 5 bus fault handler
   UsageFaultException,                   // 6 usage fault handler
   0,                                     // Reserved
   0,                                     // Reserved
   0,                                     // Reserved
   0,                                     // Reserved
   SVCHandler,                            // 11 SVCall exception handler
   DebugMonitor,                          // 12 Debug monitor handler
   0,                                     // Reserved
   PendSVC,                               // 14 The PendSVC handler
   SysTickHandler,                        // 15 SysTick handler
   WWDG_IRQHandler,                       // 16 WWDG handler
   PVD_IRQHandler,                        // 17 PVD handler
   TAMPER_IRQHandler,                     // 18 Tamper handler
   RTC_IRQHandler,                        // 19 RTC global handler
   FLASH_IRQHandler,                      // 20 Flash handler
   RCC_IRQHandler,                        // 21 RCC handler
   EXTI0_IRQHandler,                      // 22 External interrupt Line 0 handler
   EXTI1_IRQHandler,                      // 23 External interrupt Line 1 handler
   EXTI2_IRQHandler,                      // 24 External interrupt Line 2 handler
   EXTI3_IRQHandler,                      // 25 External interrupt Line 3 handler
   EXTI4_IRQHandler,                      // 26 External interrupt Line 4 handler
   DMAChannel1_IRQHandler,                // 27 DMA Stream 1 handler
   DMAChannel2_IRQHandler,                // 28 DMA Stream 2 handler
   DMAChannel3_IRQHandler,                // 29 DMA Stream 3 handler
   DMAChannel4_IRQHandler,                // 30 DMA Stream 4 handler
   DMAChannel5_IRQHandler,                // 31 DMA Stream 5 handler
   DMAChannel6_IRQHandler,                // 32 DMA Stream 6 handler
   DMAChannel7_IRQHandler,                // 33 DMA Stream 7 handler
   ADC_IRQHandler,                        // 34 ADC global interrupt handler
   USB_HP_CAN_TX_IRQHandler,              // 35 USB High Priority or CAN TX handler
   USB_LP_CAN_RX0_IRQHandler,             // 36 USB Low Priority or CAN RX0 handler
   CAN_RX1_IRQHandler,                    // 37 CAN RX1 handler
   CAN_SCE_IRQHandler,                    // 38 CAN SCE handler
   EXTI9_5_IRQHandler,                    // 39 External lines 9 to 5 interrupt handler
   TIM1_BRK_IRQHandler,                   // 40 TIM1 Break interrupt handler
   TIM1_UP_IRQHandler,                    // 41 TIM1 overflow and update interrupt handler
   TIM1_TRG_COM_IRQHandler,               // 42 TIM1 Trigger and commutation interrupts handler
   TIM1_CC_IRQHandler,                    // 43 TIM1 capture compare interrupt handler
   TIM2_IRQHandler,                       // 44 TIM2 global interrupt handler
   TIM3_IRQHandler,                       // 45 TIM3 global interrupt handler
   TIM4_IRQHandler,                       // 46 TIM4 global interrupt handler
   I2C1_EV_IRQHandler,                    // 47 I2C1 Event handler
   I2C1_ER_IRQHandler,                    // 48 I2C1 Error handler
   I2C2_EV_IRQHandler,                    // 49 I2C2 Event handler
   I2C2_ER_IRQHandler,                    // 50 I2C2 Error handler
   SPI1_IRQHandler,                       // 51 SPI1 global interrupt handler
   SPI2_IRQHandler,                       // 52 SPI2 global interrupt handler
   USART1_IRQHandler,                     // 53 USART1 global interrupt handler
   USART2_IRQHandler,                     // 54 USART2 global interrupt handler
   USART3_IRQHandler,                     // 55 USART3 global interrupt handler
   EXTI15_10_IRQHandler,                  // 56 External lines 15 to 10 interrupt handler
   RTCAlarm_IRQHandler,                   // 57 RTC Alarm interrupt handler
   USBWakeUp_IRQHandler,                  // 58 USB WakeUp interrupt handler
   DefaultHandler                         // 59 all undefined handler
};

/*******************************************************************************
* reference to linker symbols
*******************************************************************************/

extern unsigned long _etext;
extern unsigned long _data;
extern unsigned long _edata;
extern unsigned long _bss;
extern unsigned long _ebss;

/*******************************************************************************
* Function Name:   Reset
* Description:     Initial Entry after POR or SW-Reset, prepares bss section
*                 and initial values, branch to main
* Input:           None
* Output:          None
* Return:          None
*******************************************************************************/
void Reset(void)
{
   unsigned long *Src, *Dest;
   // Initialize data

   // Copy the data segment initializers from flash to SRAM.
   Src = &_etext;
   for(Dest = &_data; Dest < &_edata; )
   {
      *Dest++ = *Src++;
   }

   // Zero fill the bss segment.
   for(Dest = &_bss; Dest < &_ebss; )
   {
     *Dest++ = 0;
   }
   // Call main.
   main();
}

/************************************ EOF ***********************************/
