/*
 ********************************************************************
 * Project:   STM32-ComStick
 * File:      main.c
 *
 *
 * Date:      2008-02-12
 * Author:    Application@Hitex.de
 *
 * Rights:    Hitex Development Tools GmbH
 *            Greschbachstr. 12
 *            D-76229 Karlsruhe
 ********************************************************************
 * Description:
 *
 * - main program
 ********************************************************************
 * History:
 *
 *
 *     Initial revision
 ********************************************************************
 * This is a preliminary version.
 *
 * WARRANTY:  HITEX warrants that the media on which the SOFTWARE is
 * furnished is free from defects in materials and workmanship under
 * normal use and service for a period of ninety (90) days. HITEX entire
 * liability and your exclusive remedy shall be the replacement of the
 * SOFTWARE if the media is defective. This Warranty is void if failure
 * of the media resulted from unauthorized modification, accident, abuse,
 * or misapplication.
 *
 * DISCLAIMER:  OTHER THAN THE ABOVE WARRANTY, THE SOFTWARE IS FURNISHED
 * "AS IS" WITHOUT WARRANTY OF ANY KIND. HITEX DISCLAIMS ALL OTHER WARRANTIES,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * NEITHER HITEX NOR ITS AFFILIATES SHALL BE LIABLE FOR ANY DAMAGES ARISING
 * OUT OF THE USE OF OR INABILITY TO USE THE SOFTWARE, INCLUDING DAMAGES FOR
 * LOSS OF PROFITS, BUSINESS INTERRUPTION, OR ANY SPECIAL, INCIDENTAL, INDIRECT
 * OR CONSEQUENTIAL DAMAGES EVEN IF HITEX HAS BEEN ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGES.
 ********************************************************************/

/* Includes -----------------------------------------------------------------*/
#include "main.h"

/* Private typedef ----------------------------------------------------------*/
/* Private define -----------------------------------------------------------*/
/* Private macro ------------------------------------------------------------*/

/* Bitbanding */
/* GPIOB offset */
#define GPIOB_OFFSET                       (GPIOB_BASE)

/* GPIOE BSRR offset */
#define REG32 (volatile unsigned int*)

#define GPIOB_BSRR_OFFSET                  (GPIOB_OFFSET + 0x10)
#define GPIOB_BRR_OFFSET                   (GPIOB_OFFSET + 0x14)

/* calculate bit band address for peripherals */
#define PERIPHERAL_BBADDR( Address, Bit )  (PERIPH_BB_BASE + 32 * ((Address)- PERIPH_BASE) ) + (4 * (Bit)))

/* LED is connected to Port B, Pin 1 */
#define SET_LED_BIT   (*(REG32 (PERIPHERAL_BBADDR( GPIOB_BSRR_OFFSET, 1 )))
#define CLR_LED_BIT   (*(REG32 (PERIPHERAL_BBADDR( GPIOB_BRR_OFFSET, 1 )))


/* Private variables --------------------------------------------------------*/

/* Private function prototypes ----------------------------------------------*/
void RCC_init ( void );
void IO_init ( void );
void SYSTICK_init( void );

/* Private functions --------------------------------------------------------*/

void assert_failed(u8* file, u32 line)
{
    static u8* LastFile;
    static u32 LastLine;
    LastFile=file;
    LastLine=line;
    while(1);
}

static volatile u32 i,j;

/**
  * @brief  Main program
  * @param  None
  * @retval : None
  */
int main (void)
{

	RCC_init();

    IO_init();

    SYSTICK_init();

    while (1)
    {
        for (i=0;i<1000000;i++);
        j++;
    }
}
/**
  * @brief  Toggle the LED with each function call from IRQ service.
  * @param  None
  * @retval : None
  */
void ToggleLED( void )
{
	static u8 n=0;

	n++;

	if (n==1)
		{
		// LED ON
		GPIO_SetBits(GPIOE, GPIO_Pin_15);
		GPIO_SetBits(GPIOB, (GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_5 | GPIO_Pin_9));
		}
	if (n==2)
		{
		// LED OFF
		GPIO_ResetBits(GPIOE, GPIO_Pin_15);
		GPIO_ResetBits(GPIOB, (GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_5 | GPIO_Pin_9));
		n=0;
		}
}

/**
  * @brief  Configures the different system clocks.
  * @param  None
  * @retval : None
  */
void RCC_init ( void )
{
/* PLL and clock */
	/*!< RCC system reset(for debug purpose) */
	/*!< Set HSION bit */
	RCC->CR |= (uint32_t)0x00000001;
	/*!< Reset SW[1:0], HPRE[3:0], PPRE1[2:0], PPRE2[2:0], ADCPRE[1:0] and MCO[2:0] bits */
	RCC->CFGR &= (uint32_t)0xF8FF0000;
	/*!< Reset HSEON, CSSON and PLLON bits */
	RCC->CR &= (uint32_t)0xFEF6FFFF;
	/*!< Reset HSEBYP bit */
	RCC->CR &= (uint32_t)0xFFFBFFFF;
	/*!< Reset PLLSRC, PLLXTPRE, PLLMUL[3:0] and USBPRE bits */
	RCC->CFGR &= (uint32_t)0xFF80FFFF;
	/*!< Disable all interrupts */
	RCC->CIR = 0x00000000;

	/*!< Configure the System clock frequency, HCLK, PCLK2 and PCLK1 prescalers */
	/*!< Configure the Flash Latency cycles and enable prefetch buffer */
	__IO uint32_t StartUpCounter = 0, HSEStatus = 0;

	/*!< SYSCLK, HCLK, PCLK2 and PCLK1 configuration */
	/*!< Enable HSE */
	RCC->CR |= ((uint32_t)RCC_CR_HSEON);

	/*!< Wait till HSE is ready and if Time out is reached exit */
	do
	{
		HSEStatus = RCC->CR & RCC_CR_HSERDY;
		StartUpCounter++;
	} while((HSEStatus == 0) && (StartUpCounter != HSEStartUp_TimeOut));

	if ((RCC->CR & RCC_CR_HSERDY) != RESET)
	{
		HSEStatus = (uint32_t)0x01;
	}
	else
	{
		HSEStatus = (uint32_t)0x00;
	}

	if (HSEStatus == (uint32_t)0x01)
	{
		/*!< Enable Prefetch Buffer */
		FLASH->ACR |= FLASH_ACR_PRFTBE;

		/*!< Flash 2 wait state */
		FLASH->ACR &= (uint32_t)((uint32_t)~FLASH_ACR_LATENCY);
		FLASH->ACR |= (uint32_t)FLASH_ACR_LATENCY_2;

		/*!< HCLK = SYSCLK */
		RCC->CFGR |= (uint32_t)RCC_CFGR_HPRE_DIV1;

		/*!< PCLK2 = HCLK */
		RCC->CFGR |= (uint32_t)RCC_CFGR_PPRE2_DIV1;

		/*!< PCLK1 = HCLK */
		RCC->CFGR |= (uint32_t)RCC_CFGR_PPRE1_DIV2;

		/*!< PLLCLK = 8MHz * 9 = 72 MHz */
		RCC->CFGR &= (uint32_t)((uint32_t)~(RCC_CFGR_PLLSRC | RCC_CFGR_PLLXTPRE | RCC_CFGR_PLLMULL));
		RCC->CFGR |= (uint32_t)(RCC_CFGR_PLLSRC | RCC_CFGR_PLLMULL9);

		/*!< Enable PLL */
		RCC->CR |= RCC_CR_PLLON;

		/*!< Wait till PLL is ready */
		while((RCC->CR & RCC_CR_PLLRDY) == 0)
		{
		}

		/*!< Select PLL as system clock source */
		RCC->CFGR &= (uint32_t)((uint32_t)~(RCC_CFGR_SW));
		RCC->CFGR |= (uint32_t)RCC_CFGR_SW_PLL;

		/*!< Wait till PLL is used as system clock source */
		while ((RCC->CFGR & (uint32_t)RCC_CFGR_SWS) != (uint32_t)0x08)
		{
		}
	}
	else
	{ /*!< If HSE fails to start-up, the application will have wrong clock
         configuration. User can add here some code to deal with this error */

		/*!< Go to infinite loop */
		while (1)
		{
		}
	}
	/* Enable GPIOA, GPIOB, GPIOC and GPIOE clocks */
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA | RCC_APB2Periph_GPIOB | RCC_APB2Periph_GPIOC
                          |RCC_APB2Periph_GPIOE , ENABLE);
}

/**
  * @brief  Initialise the systick counter to generate an periodic interrupt.
  * @param  None
  * @retval : None
  */
void SYSTICK_init( void )
{
	/* Use Systick to generate a cyclic interrupt */

	SysTick_CLKSourceConfig(SysTick_CLKSource_HCLK);
	SysTick_SetReload(60*1000*250 - 1);
	SysTick_ITConfig(ENABLE);
	SysTick_CounterCmd(SysTick_Counter_Enable);
}

/**
  * @brief  Configures the LED pins on the GPIO ports.
  * @param  None
  * @retval : None
  */
void IO_init ( void )
{
	GPIO_InitTypeDef GPIO_InitStructure;

	/* LEDs */
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_9 | GPIO_Pin_5 | GPIO_Pin_1 | GPIO_Pin_0;
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
	GPIO_Init(GPIOB, &GPIO_InitStructure);

	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_15;
	GPIO_Init(GPIOE, &GPIO_InitStructure);

	// Linee aggiunte
	GPIO_InitStructure.GPIO_Pin = (GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_5 | GPIO_Pin_9);
	GPIO_Init(GPIOB, &GPIO_InitStructure);

}

/************************************** EOF *********************************/
